from sqlalchemy.ext.declarative import declared_attr
from sqlalchemy import Column, Integer, DateTime
from datetime import datetime

from app.db.base import Base


class BaseModel(Base):
    """
    Base model class that includes common fields and functionality
    for all models.
    """

    __abstract__ = True

    id = Column(Integer, primary_key=True, index=True)
    created_at = Column(DateTime, default=datetime.utcnow)
    updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow)

    @declared_attr
    def __tablename__(cls) -> str:
        """
        Generate table name automatically from the class name.
        """
        return cls.__name__.lower()
