import logging

from app.db.init_db import init_db
from app.db.session import SessionLocal

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)


def init() -> None:
    """
    Initialize the database with initial data.
    """
    db = SessionLocal()
    try:
        init_db(db)
        logger.info("Initial data created")
    finally:
        db.close()


def main() -> None:
    """
    Main function to initialize the database.
    """
    logger.info("Creating initial data")
    init()
    logger.info("Initial data creation completed")


if __name__ == "__main__":
    main()
